package com.ascendfinalproject.warehouse.controllers;

import com.ascendfinalproject.warehouse.models.WarehouseOrderRequest;
import com.ascendfinalproject.warehouse.models.WarehouseOrderResponse;
import com.ascendfinalproject.warehouse.services.WarehouseOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import javax.validation.Valid;

@RestController
@RequestMapping(value = "/api")
public class WarehouseController {

  @Autowired
  WarehouseOrderService orderService;

  @CrossOrigin
  @GetMapping(value = "/orders")
  public Flux<WarehouseOrderResponse> getOrders() {
    return orderService.getOrders();
  }

  @CrossOrigin
  @GetMapping("/orders/{id}")
  public Mono<WarehouseOrderResponse> findOrder(@PathVariable String id){
    return orderService.findOrderById(id);
  }

  @CrossOrigin
  @PostMapping(value = "/orders")
  public Mono<WarehouseOrderResponse> createOrder(@Valid @RequestBody WarehouseOrderRequest order) {
    return orderService.createOrder(order);
  }

  @CrossOrigin
  @PutMapping(value = "/orders/{id}")
  public Mono<WarehouseOrderResponse> updateOrder(@RequestBody WarehouseOrderResponse order, @PathVariable(value = "id") String id) {
    return orderService.updateOrder(order, id);
  }

  @CrossOrigin
  @DeleteMapping(value = "/orders/{id}")
  public Mono<Void> deleteOrder(@PathVariable(value = "id") String id) {
    return orderService.deleteOrder(id);
  }

  @CrossOrigin
  @DeleteMapping(value = "/orders/all")
  public Mono<Void> deleteAllOrders() {
    System.out.println("Deleted all orders");
    return orderService.deleteAllOrders();
  }

}
